clear;
t = 1e-2;
E = 10e9;
rho = 1000;
nu = 1/3;
D = E*t^3/12/(1-nu^2);
sigma = rho*t;
c = 343;
rho0 = 1.225;
cL = sqrt(E/rho);

omc = c^2/cL/t * sqrt(12) * sqrt(1-nu^2);

L = .3;

for n = 1 : 50
    kB = n*pi/L;
    om = kB^2*sqrt(D/sigma);
    k = om/c;
    
    x = linspace(0, L, 501);
    x = x(1:end-1);
    
    v = sin(kB*x);
    
    g = k*L/2;
    G = max(500,g);
    gamma = linspace(-G, G, 10001);
    Psi = v * exp(1i*(x'*gamma));
    Psi = abs(Psi) / max(abs(Psi));
    
    theta = linspace(-pi/2, pi/2, 101);
    q = interp1(gamma, Psi, g*sin(theta));
    q = q / max(abs(q));
    
    subplot(2,2,1);
    plot(x, v, 'LineWidth', 2);
    xlim([0 L]);
    xlabel('x [m]');
    ylabel('v(x)');
    subplot(2,2,3);
    plot(gamma, Psi, [-g -g], [0 1], 'r', [g g], [0 1], 'r', 'LineWidth', 2);
    xlabel('kL/2 sin(\theta)');
    ylabel('\Psi(\theta)');
    subplot(2,2,[2 4]);
    p = polar([theta theta+pi], [q fliplr(q)]);
    set(p, 'LineWidth', 2);
    
    pause;
end